<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="120"/>
        <source>Deepin Movie</source>
        <translation>Deepin 동영상 </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
        <translation>Deepin 동영상은 단순한 테두리 없는 디자인으로 디자인도 잘 되어 있고, 모든 기능을 갖춘 비디오 플레이어입니다. 여러 비디오 형식으로 로컬 및 스트리밍 미디어 재생을 지원합니다.</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="116"/>
        <source>Invalid folder</source>
        <translation>잘못된 폴더</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="130"/>
        <source>Open folder</source>
        <translation>폴더 열기</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="121"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>이 폴더를 조작할 수 있는 권한이 없습니다</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="5"/>
        <source>Auto add similar files to play</source>
        <translation>재생할 유사한 파일 자동 추가</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="6"/>
        <source>Clear playlist when exit</source>
        <translation>종료시 재생 목록 지우기</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="7"/>
        <source>Show video preview on mouseover</source>
        <translation>마우스 오버시 비디오 미리보기 표시</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="8"/>
        <source>Open a new player for each file played</source>
        <translation>재생되는 각 파일에 대해 새 플레이어 열기</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="9"/>
        <source>Pause when minimized</source>
        <translation>최소화된 경우 일시 중지</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="10"/>
        <source>Remember playback position</source>
        <translation>재생 위치 기억</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="11"/>
        <source>Path</source>
        <translation>경로</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="12"/>
        <source>Basic</source>
        <translation>기본</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="13"/>
        <source>Play</source>
        <translation>재생</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="14"/>
        <location filename="../common/settings_translation.cpp" line="19"/>
        <source>Screenshot</source>
        <translation>스크린샷</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="15"/>
        <source>Shortcuts</source>
        <translation>단축키</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="16"/>
        <source>File</source>
        <translation>파일</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="17"/>
        <source>Frame/Sound</source>
        <translation>프레임/사운드</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="18"/>
        <source>Playback</source>
        <translation>재생</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="20"/>
        <location filename="../common/settings_translation.cpp" line="21"/>
        <source>Subtitle</source>
        <translation>자막</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="22"/>
        <source>Font Style</source>
        <translation>글꼴 스타일</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="23"/>
        <source>Restore Defaults</source>
        <translation>기본값 복원</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="24"/>
        <source>Open file</source>
        <translation>파일 열기</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="25"/>
        <source>Open next</source>
        <translation>다음 열기</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="26"/>
        <source>Open previous</source>
        <translation>이전 열기</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="27"/>
        <source>Mini mode</source>
        <translation>미니 모드 </translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="28"/>
        <source>Mute</source>
        <translation>음소거</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="29"/>
        <source>Next frame</source>
        <translation>다음 프레임</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="30"/>
        <source>Previous frame</source>
        <translation>이전 프레임</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="31"/>
        <source>Volume down</source>
        <translation>볼륨 낮추기</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="32"/>
        <source>Volume up</source>
        <translation>볼륨 키우기</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="33"/>
        <source>Speed up</source>
        <translation>속도 올리기</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="34"/>
        <source>Speed down</source>
        <translation>속도 낮추기</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="35"/>
        <source>Fullscreen</source>
        <translation>전체 화면</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="36"/>
        <source>Pause/Play</source>
        <translation>멈춤/재생</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="37"/>
        <source>Playlist</source>
        <translation>재생목록</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="38"/>
        <source>Reset speed</source>
        <translation>속도 재설정</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="39"/>
        <source>Rewind</source>
        <translation>되감기</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="40"/>
        <source>Forward</source>
        <translation>앞으로</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="41"/>
        <source>Burst screenshot</source>
        <translation>버스트 스크린샷</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="42"/>
        <source>Film screenshot</source>
        <translation>필름 스크린샷</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="43"/>
        <source>0.5s backward</source>
        <translation>0.5초 뒤로</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="44"/>
        <source>0.5s forward</source>
        <translation>0.5초 앞으로</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="45"/>
        <source>Font</source>
        <translation>글꼴</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="46"/>
        <source>Font Size</source>
        <translation>글꼴 크기:</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="42"/>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="46"/>
        <source>Please enter the URL:</source>
        <translation>URL을 입력해 주세요.</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../common/actions.cpp" line="84"/>
        <location filename="../common/actions.cpp" line="269"/>
        <source>Settings</source>
        <translation>설정 </translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="108"/>
        <source>Fullscreen</source>
        <translation>전체화면</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="110"/>
        <source>Always on Top</source>
        <translation>항상 위에</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="284"/>
        <source>Film info</source>
        <translation>필름 정보</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="82"/>
        <location filename="../common/actions.cpp" line="102"/>
        <source>Open file</source>
        <translation>파일 열기</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="83"/>
        <location filename="../common/actions.cpp" line="103"/>
        <source>Open folder</source>
        <translation>폴더 열기</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="85"/>
        <source>Light theme</source>
        <translation>밝은 테마</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="104"/>
        <source>Open URL</source>
        <translation>오픈 URL</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="105"/>
        <source>Open CD/DVD</source>
        <translation>CD/DVD 열기</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="109"/>
        <source>Mini Mode</source>
        <translation>미니 모드</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="115"/>
        <source>Play Mode</source>
        <translation>재생 모드</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="118"/>
        <source>Order Play</source>
        <translation>재생 명령</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="119"/>
        <source>Shuffle Play</source>
        <translation>셔플 재생</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="120"/>
        <source>Single Play</source>
        <translation>한곡 재생</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="121"/>
        <source>Single Loop</source>
        <translation>한곡 반복</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="122"/>
        <source>List Loop</source>
        <translation>목록 반복</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="129"/>
        <source>Frame</source>
        <translation>프레임</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="132"/>
        <source>Default</source>
        <translation>기본값</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="140"/>
        <source>Clockwise</source>
        <translation>시계 방향으로</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="141"/>
        <source>Counterclockwise</source>
        <translation>반시계 방향으로</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="144"/>
        <source>Next frame</source>
        <translation>다음 프레임</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="145"/>
        <source>Previous frame</source>
        <translation>이전 프레임</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="152"/>
        <source>Sound</source>
        <translation>사운드</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="155"/>
        <source>Channel</source>
        <translation>채널</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="158"/>
        <source>Stereo</source>
        <translation>스테레오 </translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="159"/>
        <source>Left channel</source>
        <translation>왼쪽 채널</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="160"/>
        <source>Right channel</source>
        <translation>오른쪽 채널</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="166"/>
        <source>Track</source>
        <translation>트랙</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="176"/>
        <source>Subtitle</source>
        <translation>자막</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="177"/>
        <source>Load</source>
        <translation>불러오기</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="178"/>
        <source>Online Search</source>
        <translation>온라인 검색</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="182"/>
        <source>Select</source>
        <translation>선택</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="186"/>
        <source>Hide</source>
        <translation>숨기기</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="190"/>
        <source>Encodings</source>
        <translation>인코딩</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="258"/>
        <source>Screenshot</source>
        <translation>스크린샷</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="259"/>
        <source>Film Screenshot</source>
        <translation>필름 스크린샷</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="260"/>
        <source>Burst Shooting</source>
        <translation>버스트 슈팅</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="267"/>
        <source>Playlist</source>
        <translation>재생목록</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="268"/>
        <source>Film Info</source>
        <translation>필름 정보</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="282"/>
        <source>Clear playlist</source>
        <translation>재생목록 지우기</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="283"/>
        <source>Display in file manager</source>
        <translation>파일 관리자에 표시</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
        <source>Duration: %1</source>
        <translation>재생 시간: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
        <source>Resolution: %1</source>
        <translation>해상도: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
        <source>Size: %1</source>
        <translation>크기: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
        <source>Save</source>
        <translation>저장</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../common/mainwindow.cpp" line="720"/>
        <location filename="../common/mainwindow.cpp" line="1821"/>
        <source>Load successfully</source>
        <translation>불러오기 성공</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="720"/>
        <location filename="../common/mainwindow.cpp" line="1821"/>
        <source>Load failed</source>
        <translation>불러오기 실패</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1424"/>
        <source>No device found</source>
        <translation>장치를 찾을 수 없음</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1442"/>
        <source>Parse Failed</source>
        <translation>구문분석 실패</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1449"/>
        <source>Open folder</source>
        <translation>폴더 열기</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1464"/>
        <location filename="../common/mainwindow.cpp" line="1481"/>
        <location filename="../common/mainwindow.cpp" line="1816"/>
        <source>Open file</source>
        <translation>파일 열기</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1466"/>
        <location filename="../common/mainwindow.cpp" line="1483"/>
        <source>All videos (%1)</source>
        <translation>모든 동영상 (%1)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1684"/>
        <source>Muted</source>
        <translation>음소거됨</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1687"/>
        <location filename="../common/mainwindow.cpp" line="1699"/>
        <location filename="../common/mainwindow.cpp" line="1709"/>
        <location filename="../common/mainwindow.cpp" line="1716"/>
        <source>Volume: %1%</source>
        <translation>볼륨: %1%</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1781"/>
        <location filename="../common/mainwindow.cpp" line="1789"/>
        <source>Subtitle %1: %2s</source>
        <translation>자막 %1: %2초</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1782"/>
        <location filename="../common/mainwindow.cpp" line="1790"/>
        <source>delayed</source>
        <translation>지연됨</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1782"/>
        <location filename="../common/mainwindow.cpp" line="1790"/>
        <source>advanced</source>
        <translation>고급</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1797"/>
        <location filename="../common/mainwindow.cpp" line="1804"/>
        <location filename="../common/mainwindow.cpp" line="1811"/>
        <source>Speed: %1x</source>
        <translation>속도: %1x</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1818"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <translation>자막 (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1880"/>
        <source>View</source>
        <translation>ㅂㅗ기</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1891"/>
        <source>Movie Screenshot</source>
        <translation>동영상 스크린샷</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1892"/>
        <source>Saved to</source>
        <translation>저장됨:</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1906"/>
        <location filename="../common/mainwindow.cpp" line="1989"/>
        <source>The screenshot is saved</source>
        <translation>스크린샷이 저장 되었습니다</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1906"/>
        <source>Failed to save the screenshot</source>
        <translation>스크린샷을 저장하지 못했습니다</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="2076"/>
        <location filename="../common/mainwindow.cpp" line="2782"/>
        <source>Invalid file: %1</source>
        <translation>잘못된 파일: %1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <location filename="../libdmr/playlist_model.h" line="67"/>
        <source>%1G</source>
        <translation>%1G</translation>
    </message>
    <message>
        <location filename="../libdmr/playlist_model.h" line="69"/>
        <source>%1M</source>
        <translation>%1M</translation>
    </message>
    <message>
        <location filename="../libdmr/playlist_model.h" line="71"/>
        <source>%1K</source>
        <translation>%1K</translation>
    </message>
    <message>
        <location filename="../libdmr/playlist_model.h" line="73"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
        <source>File Type:</source>
        <translation>파일 유형:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
        <source>Resolution:</source>
        <translation>해상도:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
        <source>File Size:</source>
        <translation>파일 크기:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
        <source>Duration:</source>
        <translation>재생 시간:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
        <source>File Path:</source>
        <translation>파일 경로:</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1034"/>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1052"/>
        <source>[internal]</source>
        <translation>[내부]</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../widgets/playlist_widget.cpp" line="192"/>
        <location filename="../widgets/playlist_widget.cpp" line="227"/>
        <location filename="../widgets/playlist_widget.cpp" line="402"/>
        <source>File does not exist</source>
        <translation>파일이 없습니다</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../common/dmr_settings.cpp" line="155"/>
        <source>%1/DMovie%2.jpg</source>
        <translation>%1/DMovie%2.jpg</translation>
    </message>
    <message>
        <location filename="../common/dmr_settings.cpp" line="161"/>
        <source>%1/DMovie%2(%3).jpg</source>
        <translation>%1/DMovie%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="889"/>
        <source>Play</source>
        <translation>재생</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="685"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="686"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="687"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Subtitles</source>
        <translation>자막</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="688"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Playlist</source>
        <translation>재생 목록</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="689"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="876"/>
        <source>Fullscreen</source>
        <translation>전체화면</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="683"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Play/Pause</source>
        <translation>재생 / 일시정지</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="873"/>
        <source>Exit fullscreen</source>
        <translation>전체화면 종료</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="886"/>
        <source>Pause</source>
        <translation>일시정지</translation>
    </message>
</context>
</TS>